Enum BidiPairedBracketType

enum BidiPairedBracketType

The enum represents Bidi_Paired_Bracket_Type.

It does not implement EnumeratedProperty, instead it can be obtained through the bitpacked BidiMirroringGlyph property.

If you have a use case this property without also needing the BidiMirroringGlyph property, and need to optimize data size, please file an issue.

Variants

Open

Represents Bidi_Paired_Bracket_Type=Open.

Close

Represents Bidi_Paired_Bracket_Type=Close.

None

Represents Bidi_Paired_Bracket_Type=None.

Implementations

impl Clone for BidiPairedBracketType

fn clone(self: &Self) -> BidiPairedBracketType

impl Copy for BidiPairedBracketType

impl Debug for BidiPairedBracketType

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for BidiPairedBracketType

fn default() -> BidiPairedBracketType

impl Eq for BidiPairedBracketType

impl Freeze for BidiPairedBracketType

impl PartialEq for BidiPairedBracketType

fn eq(self: &Self, other: &BidiPairedBracketType) -> bool

impl RefUnwindSafe for BidiPairedBracketType

impl Send for BidiPairedBracketType

impl StructuralPartialEq for BidiPairedBracketType

impl Sync for BidiPairedBracketType

impl Unpin for BidiPairedBracketType

impl UnsafeUnpin for BidiPairedBracketType

impl UnwindSafe for BidiPairedBracketType

impl<T> Any for BidiPairedBracketType

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for BidiPairedBracketType

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for BidiPairedBracketType

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for BidiPairedBracketType

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for BidiPairedBracketType

impl<T> From for BidiPairedBracketType

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for BidiPairedBracketType

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for BidiPairedBracketType

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for BidiPairedBracketType

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for BidiPairedBracketType

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>