Struct AsciiHexDigit

struct AsciiHexDigit

ASCII characters commonly used for the representation of hexadecimal numbers.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::AsciiHexDigit;

let ascii_hex_digit = CodePointSetData::new::<AsciiHexDigit>();

assert!(ascii_hex_digit.contains('3'));
assert!(!ascii_hex_digit.contains(''));  // U+0A69 GURMUKHI DIGIT THREE
assert!(ascii_hex_digit.contains('A'));
assert!(!ascii_hex_digit.contains('Ä'));  // U+00C4 LATIN CAPITAL LETTER A WITH DIAERESIS

Implementations

impl BinaryProperty for AsciiHexDigit

impl Debug for AsciiHexDigit

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for AsciiHexDigit

impl RefUnwindSafe for AsciiHexDigit

impl Send for AsciiHexDigit

impl Sync for AsciiHexDigit

impl Unpin for AsciiHexDigit

impl UnsafeUnpin for AsciiHexDigit

impl UnwindSafe for AsciiHexDigit

impl<T> Any for AsciiHexDigit

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AsciiHexDigit

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AsciiHexDigit

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for AsciiHexDigit

impl<T> From for AsciiHexDigit

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for AsciiHexDigit

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AsciiHexDigit

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AsciiHexDigit

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>