Struct Dash

struct Dash

Punctuation characters explicitly called out as dashes in the Unicode Standard, plus their compatibility equivalents.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::Dash;

let dash = CodePointSetData::new::<Dash>();

assert!(dash.contains(''));  // U+2E3A TWO-EM DASH
assert!(dash.contains('-'));  // U+002D
assert!(!dash.contains('='));  // U+003D

Implementations

impl BinaryProperty for Dash

impl Debug for Dash

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Dash

impl RefUnwindSafe for Dash

impl Send for Dash

impl Sync for Dash

impl Unpin for Dash

impl UnsafeUnpin for Dash

impl UnwindSafe for Dash

impl<T> Any for Dash

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Dash

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Dash

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Dash

impl<T> From for Dash

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Dash

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Dash

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Dash

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>