Struct DefaultIgnorableCodePoint

struct DefaultIgnorableCodePoint

For programmatic determination of default ignorable code points.

New characters that should be ignored in rendering (unless explicitly supported) will be assigned in these ranges, permitting programs to correctly handle the default rendering of such characters when not otherwise supported.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::DefaultIgnorableCodePoint;

let default_ignorable_code_point = CodePointSetData::new::<DefaultIgnorableCodePoint>();

assert!(default_ignorable_code_point.contains('\u{180B}'));  // MONGOLIAN FREE VARIATION SELECTOR ONE
assert!(!default_ignorable_code_point.contains('E'));

Implementations

impl BinaryProperty for DefaultIgnorableCodePoint

impl Debug for DefaultIgnorableCodePoint

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for DefaultIgnorableCodePoint

impl RefUnwindSafe for DefaultIgnorableCodePoint

impl Send for DefaultIgnorableCodePoint

impl Sync for DefaultIgnorableCodePoint

impl Unpin for DefaultIgnorableCodePoint

impl UnsafeUnpin for DefaultIgnorableCodePoint

impl UnwindSafe for DefaultIgnorableCodePoint

impl<T> Any for DefaultIgnorableCodePoint

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DefaultIgnorableCodePoint

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DefaultIgnorableCodePoint

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for DefaultIgnorableCodePoint

impl<T> From for DefaultIgnorableCodePoint

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DefaultIgnorableCodePoint

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DefaultIgnorableCodePoint

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DefaultIgnorableCodePoint

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>