Struct Deprecated
struct Deprecated
Deprecated characters.
No characters will ever be removed from the standard, but the usage of deprecated characters is strongly discouraged.
Example
use CodePointSetData;
use Deprecated;
let deprecated = ;
assert!; // U+17A3 KHMER INDEPENDENT VOWEL QAQ
assert!;
Implementations
impl BinaryProperty for Deprecated
impl Debug for Deprecated
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Deprecated
impl RefUnwindSafe for Deprecated
impl Send for Deprecated
impl Sync for Deprecated
impl Unpin for Deprecated
impl UnsafeUnpin for Deprecated
impl UnwindSafe for Deprecated
impl<T> Any for Deprecated
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Deprecated
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Deprecated
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for Deprecated
impl<T> From for Deprecated
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Deprecated
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Deprecated
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Deprecated
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>