Struct Extender

struct Extender

Characters whose principal function is to extend the value of a preceding alphabetic character or to extend the shape of adjacent characters.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::Extender;

let extender = CodePointSetData::new::<Extender>();

assert!(extender.contains(''));  // U+30FE KATAKANA VOICED ITERATION MARK
assert!(extender.contains(''));  // U+30FC KATAKANA-HIRAGANA PROLONGED SOUND MARK
assert!(!extender.contains(''));  // U+30FB KATAKANA MIDDLE DOT

Implementations

impl BinaryProperty for Extender

impl Debug for Extender

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Extender

impl RefUnwindSafe for Extender

impl Send for Extender

impl Sync for Extender

impl Unpin for Extender

impl UnsafeUnpin for Extender

impl UnwindSafe for Extender

impl<T> Any for Extender

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Extender

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Extender

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Extender

impl<T> From for Extender

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Extender

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Extender

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Extender

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>