Struct GraphemeBase
struct GraphemeBase
Property used together with the definition of Standard Korean Syllable Block to define "Grapheme base".
See D58 in Chapter 3, Conformance in the Unicode Standard.
Example
use CodePointSetData;
use GraphemeBase;
let grapheme_base = ;
assert!; // U+0D15 MALAYALAM LETTER KA
assert!; // U+0D3F MALAYALAM VOWEL SIGN I
assert!; // U+0D3E MALAYALAM VOWEL SIGN AA
Implementations
impl BinaryProperty for GraphemeBase
impl Debug for GraphemeBase
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for GraphemeBase
impl RefUnwindSafe for GraphemeBase
impl Send for GraphemeBase
impl Sync for GraphemeBase
impl Unpin for GraphemeBase
impl UnsafeUnpin for GraphemeBase
impl UnwindSafe for GraphemeBase
impl<T> Any for GraphemeBase
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for GraphemeBase
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for GraphemeBase
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for GraphemeBase
impl<T> From for GraphemeBase
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for GraphemeBase
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for GraphemeBase
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for GraphemeBase
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>