Struct GraphemeLink

struct GraphemeLink

Deprecated property.

Formerly proposed for programmatic determination of grapheme cluster boundaries.

Implementations

impl BinaryProperty for GraphemeLink

impl Debug for GraphemeLink

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for GraphemeLink

impl RefUnwindSafe for GraphemeLink

impl Send for GraphemeLink

impl Sync for GraphemeLink

impl Unpin for GraphemeLink

impl UnsafeUnpin for GraphemeLink

impl UnwindSafe for GraphemeLink

impl<T> Any for GraphemeLink

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GraphemeLink

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GraphemeLink

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for GraphemeLink

impl<T> From for GraphemeLink

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for GraphemeLink

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GraphemeLink

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GraphemeLink

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>