Struct HexDigit
struct HexDigit
Characters commonly used for the representation of hexadecimal numbers, plus their compatibility equivalents.
Example
use CodePointSetData;
use HexDigit;
let hex_digit = ;
assert!;
assert!; // U+0A69 GURMUKHI DIGIT THREE
assert!;
assert!; // U+FF46 FULLWIDTH LATIN SMALL LETTER F
assert!; // U+FF26 FULLWIDTH LATIN CAPITAL LETTER F
assert!; // U+00C4 LATIN CAPITAL LETTER A WITH DIAERESIS
Implementations
impl BinaryProperty for HexDigit
impl Debug for HexDigit
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for HexDigit
impl RefUnwindSafe for HexDigit
impl Send for HexDigit
impl Sync for HexDigit
impl Unpin for HexDigit
impl UnsafeUnpin for HexDigit
impl UnwindSafe for HexDigit
impl<T> Any for HexDigit
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for HexDigit
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for HexDigit
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for HexDigit
impl<T> From for HexDigit
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for HexDigit
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for HexDigit
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for HexDigit
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>