Struct Hyphen

struct Hyphen

Deprecated property.

Dashes which are used to mark connections between pieces of words, plus the Katakana middle dot.

Implementations

impl BinaryProperty for Hyphen

impl Debug for Hyphen

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Hyphen

impl RefUnwindSafe for Hyphen

impl Send for Hyphen

impl Sync for Hyphen

impl Unpin for Hyphen

impl UnsafeUnpin for Hyphen

impl UnwindSafe for Hyphen

impl<T> Any for Hyphen

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Hyphen

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Hyphen

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Hyphen

impl<T> From for Hyphen

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Hyphen

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Hyphen

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Hyphen

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>