Struct IdContinue

struct IdContinue

Characters that can come after the first character in an identifier.

If using NFKC to fold differences between characters, use XidContinue instead. See Unicode Standard Annex #31 for more details.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::IdContinue;

let id_continue = CodePointSetData::new::<IdContinue>();

assert!(id_continue.contains('x'));
assert!(id_continue.contains('1'));
assert!(id_continue.contains('_'));
assert!(id_continue.contains('ߝ'));  // U+07DD NKO LETTER FA
assert!(!id_continue.contains(''));  // U+24E7 CIRCLED LATIN SMALL LETTER X
assert!(id_continue.contains('\u{FC5E}'));  // ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM

Implementations

impl BinaryProperty for IdContinue

impl Debug for IdContinue

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for IdContinue

impl RefUnwindSafe for IdContinue

impl Send for IdContinue

impl Sync for IdContinue

impl Unpin for IdContinue

impl UnsafeUnpin for IdContinue

impl UnwindSafe for IdContinue

impl<T> Any for IdContinue

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for IdContinue

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for IdContinue

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for IdContinue

impl<T> From for IdContinue

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for IdContinue

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for IdContinue

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for IdContinue

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>