Struct JoinControl

struct JoinControl

Format control characters which have specific functions for control of cursive joining and ligation.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::JoinControl;

let join_control = CodePointSetData::new::<JoinControl>();

assert!(join_control.contains('\u{200C}'));  // ZERO WIDTH NON-JOINER
assert!(join_control.contains('\u{200D}'));  // ZERO WIDTH JOINER
assert!(!join_control.contains('\u{200E}'));

Implementations

impl BinaryProperty for JoinControl

impl Debug for JoinControl

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for JoinControl

impl RefUnwindSafe for JoinControl

impl Send for JoinControl

impl Sync for JoinControl

impl Unpin for JoinControl

impl UnsafeUnpin for JoinControl

impl UnwindSafe for JoinControl

impl<T> Any for JoinControl

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for JoinControl

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for JoinControl

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for JoinControl

impl<T> From for JoinControl

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for JoinControl

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for JoinControl

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for JoinControl

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>