Struct Radical

struct Radical

Characters used in the definition of Ideographic Description Sequences.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::Radical;

let radical = CodePointSetData::new::<Radical>();

assert!(radical.contains(''));  // U+2E86 CJK RADICAL BOX
assert!(!radical.contains(''));  // U+F95E CJK COMPATIBILITY IDEOGRAPH-F95E

Implementations

impl BinaryProperty for Radical

impl Debug for Radical

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Radical

impl RefUnwindSafe for Radical

impl Send for Radical

impl Sync for Radical

impl Unpin for Radical

impl UnsafeUnpin for Radical

impl UnwindSafe for Radical

impl<T> Any for Radical

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Radical

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Radical

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Radical

impl<T> From for Radical

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Radical

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Radical

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Radical

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>