Struct SegmentStarter

struct SegmentStarter

Characters that are starters in terms of Unicode normalization and combining character sequences.

Implementations

impl BinaryProperty for SegmentStarter

impl Debug for SegmentStarter

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for SegmentStarter

impl RefUnwindSafe for SegmentStarter

impl Send for SegmentStarter

impl Sync for SegmentStarter

impl Unpin for SegmentStarter

impl UnsafeUnpin for SegmentStarter

impl UnwindSafe for SegmentStarter

impl<T> Any for SegmentStarter

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SegmentStarter

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SegmentStarter

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for SegmentStarter

impl<T> From for SegmentStarter

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for SegmentStarter

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SegmentStarter

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SegmentStarter

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>