Struct SoftDotted

struct SoftDotted

Characters with a "soft dot", like i or j.

An accent placed on these characters causes the dot to disappear.

Example

use icu::properties::CodePointSetData;
use icu::properties::props::SoftDotted;

let soft_dotted = CodePointSetData::new::<SoftDotted>();

assert!(soft_dotted.contains('і'));  //U+0456 CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
assert!(!soft_dotted.contains('ı'));  // U+0131 LATIN SMALL LETTER DOTLESS I

Implementations

impl BinaryProperty for SoftDotted

impl Debug for SoftDotted

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for SoftDotted

impl RefUnwindSafe for SoftDotted

impl Send for SoftDotted

impl Sync for SoftDotted

impl Unpin for SoftDotted

impl UnsafeUnpin for SoftDotted

impl UnwindSafe for SoftDotted

impl<T> Any for SoftDotted

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for SoftDotted

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for SoftDotted

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for SoftDotted

impl<T> From for SoftDotted

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for SoftDotted

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for SoftDotted

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for SoftDotted

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>