Struct TerminalPunctuation
struct TerminalPunctuation
Punctuation characters that generally mark the end of textual units.
Example
use CodePointSetData;
use TerminalPunctuation;
let terminal_punctuation = ;
assert!;
assert!;
assert!; // U+1AA8 TAI THAM SIGN KAAN
assert!;
assert!; // U+00BF INVERTED QUESTION MARK
Implementations
impl BinaryProperty for TerminalPunctuation
impl Debug for TerminalPunctuation
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for TerminalPunctuation
impl RefUnwindSafe for TerminalPunctuation
impl Send for TerminalPunctuation
impl Sync for TerminalPunctuation
impl Unpin for TerminalPunctuation
impl UnsafeUnpin for TerminalPunctuation
impl UnwindSafe for TerminalPunctuation
impl<T> Any for TerminalPunctuation
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for TerminalPunctuation
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for TerminalPunctuation
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for TerminalPunctuation
impl<T> From for TerminalPunctuation
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for TerminalPunctuation
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for TerminalPunctuation
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for TerminalPunctuation
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>