Struct XidContinue
struct XidContinue
Characters that can come after the first character in an identifier.
See Unicode Standard Annex #31 for more details.
Example
use CodePointSetData;
use XidContinue;
let xid_continue = ;
assert!;
assert!;
assert!;
assert!; // U+07DD NKO LETTER FA
assert!; // U+24E7 CIRCLED LATIN SMALL LETTER X
assert!; // ARABIC LIGATURE SHADDA WITH DAMMATAN ISOLATED FORM
Implementations
impl BinaryProperty for XidContinue
impl Debug for XidContinue
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for XidContinue
impl RefUnwindSafe for XidContinue
impl Send for XidContinue
impl Sync for XidContinue
impl Unpin for XidContinue
impl UnsafeUnpin for XidContinue
impl UnwindSafe for XidContinue
impl<T> Any for XidContinue
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for XidContinue
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for XidContinue
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for XidContinue
impl<T> From for XidContinue
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for XidContinue
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for XidContinue
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for XidContinue
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>