#[non_exhaustive]pub enum PropertyCodePointMap<'data, T: TrieValue> {
CodePointTrie(CodePointTrie<'data, T>),
}Expand description
A map efficiently storing data about individual characters.
This data enum is extensible, more backends may be added in the future. Old data can be used with newer code but not vice versa.
๐ง This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. While the serde representation of data structs is guaranteed
to be stable, their Rust representation might not be. Use with caution.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CodePointTrie(CodePointTrie<'data, T>)
A codepoint trie storing the data