Enum PropertyUnicodeSet

enum PropertyUnicodeSet<'data>

A set of characters and strings which share a particular property value.

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. While the serde representation of data structs is guaranteed to be stable, their Rust representation might not be. Use with caution.

Variants

CPInversionListStrList(icu_collections::codepointinvliststringlist::CodePointInversionListAndStringList<'data>)

A set representing characters in an inversion list, and the strings in a list.

Implementations

impl MaybeAsVarULE for PropertyUnicodeSet<'_>

impl<'a> Yokeable for PropertyUnicodeSet<'static>

fn transform(self: &'a Self) -> &'a <Self as >::Output
fn transform_owned(self: Self) -> <Self as >::Output
unsafe fn make(this: <Self as >::Output) -> Self
fn transform_mut<F>(self: &'a mut Self, f: F)
where
    F: 'static + for<'b> FnOnce(&'b mut <Self as >::Output)

impl<'data> Clone for PropertyUnicodeSet<'data>

fn clone(self: &Self) -> PropertyUnicodeSet<'data>

impl<'data> Debug for PropertyUnicodeSet<'data>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'data> Eq for PropertyUnicodeSet<'data>

impl<'data> Freeze for PropertyUnicodeSet<'data>

impl<'data> PartialEq for PropertyUnicodeSet<'data>

fn eq(self: &Self, other: &PropertyUnicodeSet<'data>) -> bool

impl<'data> RefUnwindSafe for PropertyUnicodeSet<'data>

impl<'data> Send for PropertyUnicodeSet<'data>

impl<'data> StructuralPartialEq for PropertyUnicodeSet<'data>

impl<'data> Sync for PropertyUnicodeSet<'data>

impl<'data> Unpin for PropertyUnicodeSet<'data>

impl<'data> UnsafeUnpin for PropertyUnicodeSet<'data>

impl<'data> UnwindSafe for PropertyUnicodeSet<'data>

impl<'zf, 'zf_inner> ZeroFrom for PropertyUnicodeSet<'zf>

fn zero_from(this: &'zf PropertyUnicodeSet<'zf_inner>) -> Self

impl<T> Any for PropertyUnicodeSet<'data>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PropertyUnicodeSet<'data>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PropertyUnicodeSet<'data>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for PropertyUnicodeSet<'data>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for PropertyUnicodeSet<'data>

impl<T> From for PropertyUnicodeSet<'data>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for PropertyUnicodeSet<'data>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for PropertyUnicodeSet<'data>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PropertyUnicodeSet<'data>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PropertyUnicodeSet<'data>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>