Struct PropertyEnumToValueNameSparseMap

struct PropertyEnumToValueNameSparseMap<'data> { ... }

A mapping of property values to their names. A single instance of this map will only cover either long or short names, determined whilst loading data.

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. While the serde representation of data structs is guaranteed to be stable, their Rust representation might not be. Use with caution.

Fields

map: ZeroMap<'data, u16, str>

A map from the value discriminant to the names

Implementations

impl MaybeAsVarULE for PropertyEnumToValueNameSparseMap<'_>

impl<'a> Yokeable for PropertyEnumToValueNameSparseMap<'static>

fn transform(self: &'a Self) -> &'a <Self as >::Output
fn transform_owned(self: Self) -> <Self as >::Output
unsafe fn make(this: <Self as >::Output) -> Self
fn transform_mut<F>(self: &'a mut Self, f: F)
where
    F: 'static + for<'b> FnOnce(&'b mut <Self as >::Output)

impl<'data> Clone for PropertyEnumToValueNameSparseMap<'data>

fn clone(self: &Self) -> PropertyEnumToValueNameSparseMap<'data>

impl<'data> Debug for PropertyEnumToValueNameSparseMap<'data>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<'data> Freeze for PropertyEnumToValueNameSparseMap<'data>

impl<'data> PartialEq for PropertyEnumToValueNameSparseMap<'data>

fn eq(self: &Self, other: &PropertyEnumToValueNameSparseMap<'data>) -> bool

impl<'data> RefUnwindSafe for PropertyEnumToValueNameSparseMap<'data>

impl<'data> Send for PropertyEnumToValueNameSparseMap<'data>

impl<'data> StructuralPartialEq for PropertyEnumToValueNameSparseMap<'data>

impl<'data> Sync for PropertyEnumToValueNameSparseMap<'data>

impl<'data> Unpin for PropertyEnumToValueNameSparseMap<'data>

impl<'data> UnsafeUnpin for PropertyEnumToValueNameSparseMap<'data>

impl<'data> UnwindSafe for PropertyEnumToValueNameSparseMap<'data>

impl<'zf, 'zf_inner> ZeroFrom for PropertyEnumToValueNameSparseMap<'zf>

fn zero_from(this: &'zf PropertyEnumToValueNameSparseMap<'zf_inner>) -> Self

impl<T> Any for PropertyEnumToValueNameSparseMap<'data>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PropertyEnumToValueNameSparseMap<'data>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PropertyEnumToValueNameSparseMap<'data>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for PropertyEnumToValueNameSparseMap<'data>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> ErasedDestructor for PropertyEnumToValueNameSparseMap<'data>

impl<T> From for PropertyEnumToValueNameSparseMap<'data>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> ToOwned for PropertyEnumToValueNameSparseMap<'data>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T, U> Into for PropertyEnumToValueNameSparseMap<'data>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PropertyEnumToValueNameSparseMap<'data>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PropertyEnumToValueNameSparseMap<'data>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>