Struct PropertyNamesLong

struct PropertyNamesLong<T: NamedEnumeratedProperty> { ... }

A struct capable of looking up a property name from a value Access its data by calling [Self::as_borrowed()] and using the methods on PropertyNamesLongBorrowed.

Example

use icu::properties::props::CanonicalCombiningClass;
use icu::properties::PropertyNamesLong;

let names = PropertyNamesLong::<CanonicalCombiningClass>::new();
assert_eq!(
    names.get(CanonicalCombiningClass::KanaVoicing),
    Some("Kana_Voicing")
);
assert_eq!(
    names.get(CanonicalCombiningClass::AboveLeft),
    Some("Above_Left")
);

Implementations

impl<T: NamedEnumeratedProperty> PropertyNamesLong<T>

fn new() -> PropertyNamesLongBorrowed<'static, T>

Creates a new instance of PropertyNamesLongBorrowed<T>.

Enabled with the compiled_data Cargo feature.

📚 Help choosing a constructor

fn try_new_unstable<impl DataProvider<T::DataMarkerLong> + ?Sized: DataProvider<<T as >::DataMarkerLong> + ?Sized>(provider: &impl DataProvider<<T as >::DataMarkerLong> + ?Sized) -> Result<Self, DataError>

A version of Self::new that uses custom data provided by a DataProvider.

📚 Help choosing a constructor

⚠️ The bounds on provider may change over time, including in SemVer minor releases.
fn as_borrowed(self: &Self) -> PropertyNamesLongBorrowed<'_, T>

Construct a borrowed version of this type that can be queried.

This avoids a potential small underlying cost per API call (like get_static()) by consolidating it up front.

impl<T> Any for PropertyNamesLong<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for PropertyNamesLong<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for PropertyNamesLong<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for PropertyNamesLong<T>

impl<T> Freeze for PropertyNamesLong<T>

impl<T> From for PropertyNamesLong<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> RefUnwindSafe for PropertyNamesLong<T>

impl<T> Send for PropertyNamesLong<T>

impl<T> Sync for PropertyNamesLong<T>

impl<T> Unpin for PropertyNamesLong<T>

impl<T> UnsafeUnpin for PropertyNamesLong<T>

impl<T> UnwindSafe for PropertyNamesLong<T>

impl<T, U> Into for PropertyNamesLong<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for PropertyNamesLong<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for PropertyNamesLong<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: NamedEnumeratedProperty> Debug for PropertyNamesLong<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result