Struct CaseSensitive
struct CaseSensitive
Characters that are either the source of a case mapping or in the target of a case mapping.
Implementations
impl BinaryProperty for CaseSensitive
impl Debug for CaseSensitive
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for CaseSensitive
impl RefUnwindSafe for CaseSensitive
impl Send for CaseSensitive
impl Sync for CaseSensitive
impl Unpin for CaseSensitive
impl UnsafeUnpin for CaseSensitive
impl UnwindSafe for CaseSensitive
impl<T> Any for CaseSensitive
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CaseSensitive
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CaseSensitive
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for CaseSensitive
impl<T> From for CaseSensitive
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for CaseSensitive
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CaseSensitive
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CaseSensitive
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>