Struct ExtendedPictographic
struct ExtendedPictographic
Pictographic symbols, as well as reserved ranges in blocks largely associated with emoji characters
Example
use CodePointSetData;
use ExtendedPictographic;
let extended_pictographic = ;
assert!; // U+1F973 FACE WITH PARTY HORN AND PARTY HAT
assert!; // U+1F1EA REGIONAL INDICATOR SYMBOL LETTER E
Implementations
impl BinaryProperty for ExtendedPictographic
impl Debug for ExtendedPictographic
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ExtendedPictographic
impl RefUnwindSafe for ExtendedPictographic
impl Send for ExtendedPictographic
impl Sync for ExtendedPictographic
impl Unpin for ExtendedPictographic
impl UnsafeUnpin for ExtendedPictographic
impl UnwindSafe for ExtendedPictographic
impl<T> Any for ExtendedPictographic
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ExtendedPictographic
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ExtendedPictographic
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for ExtendedPictographic
impl<T> From for ExtendedPictographic
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ExtendedPictographic
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ExtendedPictographic
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ExtendedPictographic
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>