Struct HangulSyllableType
struct HangulSyllableType(_)
Enumerated property Hangul_Syllable_Type
The Unicode standard provides both precomposed Hangul syllables and conjoining Jamo to compose arbitrary Hangul syllables. This property provides that ontology of Hangul code points.
For more information, see the Unicode Korean FAQ.
Example
use ;
assert_eq!; // U+1100
assert_eq!; // U+AC00
Implementations
impl HangulSyllableType
const fn to_icu4c_value(self: Self) -> u8Returns an ICU4C
UHangulSyllableTypevalue.const fn from_icu4c_value(value: u8) -> SelfConstructor from an ICU4C
UHangulSyllableTypevalue.
impl HangulSyllableType
impl AsULE for HangulSyllableType
fn to_unaligned(self: Self) -> <Self as >::ULEfn from_unaligned(unaligned: <Self as >::ULE) -> Self
impl Clone for HangulSyllableType
fn clone(self: &Self) -> HangulSyllableType
impl Copy for HangulSyllableType
impl Debug for HangulSyllableType
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl EnumeratedProperty for HangulSyllableType
impl Eq for HangulSyllableType
impl Freeze for HangulSyllableType
impl Hash for HangulSyllableType
fn hash<__H: $crate::hash::Hasher>(self: &Self, state: &mut __H)
impl NamedEnumeratedProperty for HangulSyllableType
impl Ord for HangulSyllableType
fn cmp(self: &Self, other: &HangulSyllableType) -> Ordering
impl ParseableEnumeratedProperty for HangulSyllableType
impl PartialEq for HangulSyllableType
fn eq(self: &Self, other: &HangulSyllableType) -> bool
impl PartialOrd for HangulSyllableType
fn partial_cmp(self: &Self, other: &HangulSyllableType) -> Option<Ordering>
impl RefUnwindSafe for HangulSyllableType
impl Send for HangulSyllableType
impl StructuralPartialEq for HangulSyllableType
impl Sync for HangulSyllableType
impl TrieValue for HangulSyllableType
fn try_from_u32(i: u32) -> Result<Self, <Self as >::TryFromU32Error>fn to_u32(self: Self) -> u32
impl Unpin for HangulSyllableType
impl UnsafeUnpin for HangulSyllableType
impl UnwindSafe for HangulSyllableType
impl<T> Any for HangulSyllableType
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for HangulSyllableType
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for HangulSyllableType
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for HangulSyllableType
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> ErasedDestructor for HangulSyllableType
impl<T> From for HangulSyllableType
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for HangulSyllableType
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for HangulSyllableType
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for HangulSyllableType
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for HangulSyllableType
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>