Struct Radical
struct Radical
Characters used in the definition of Ideographic Description Sequences.
Example
use CodePointSetData;
use Radical;
let radical = ;
assert!; // U+2E86 CJK RADICAL BOX
assert!; // U+F95E CJK COMPATIBILITY IDEOGRAPH-F95E
Implementations
impl BinaryProperty for Radical
impl Debug for Radical
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Radical
impl RefUnwindSafe for Radical
impl Send for Radical
impl Sync for Radical
impl Unpin for Radical
impl UnsafeUnpin for Radical
impl UnwindSafe for Radical
impl<T> Any for Radical
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Radical
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Radical
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for Radical
impl<T> From for Radical
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Radical
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Radical
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Radical
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>