Trait BinaryProperty
trait BinaryProperty: crate::private::Sealed + Sized
A binary Unicode character property.
The descriptions of most properties are taken from TR44, the documentation for the
Unicode Character Database. Some properties are instead defined in TR18, the
documentation for Unicode regular expressions. In particular, Annex C of this document
defines properties for POSIX compatibility.
🚫 This trait is sealed; it cannot be implemented by user code. If an API requests an item that implements this
trait, please consider using a type from the implementors listed below.
Provided Methods
fn for_char(ch: char) -> boolConvenience method for
CodePointSetData::new().contains(ch)✨ Enabled with the
compiled_dataCargo feature.
Implementors
impl BinaryProperty for Mathimpl BinaryProperty for ChangesWhenTitlecasedimpl BinaryProperty for XidContinueimpl BinaryProperty for IdsTrinaryOperatorimpl BinaryProperty for ChangesWhenCasefoldedimpl BinaryProperty for Uppercaseimpl BinaryProperty for IdContinueimpl BinaryProperty for Blankimpl BinaryProperty for CaseSensitiveimpl BinaryProperty for GraphemeExtendimpl BinaryProperty for Alnumimpl BinaryProperty for Radicalimpl BinaryProperty for Extenderimpl BinaryProperty for PatternWhiteSpaceimpl BinaryProperty for EmojiComponentimpl BinaryProperty for NfdInertimpl BinaryProperty for Deprecatedimpl BinaryProperty for Lowercaseimpl BinaryProperty for ChangesWhenLowercasedimpl BinaryProperty for Xdigitimpl BinaryProperty for IdsBinaryOperatorimpl BinaryProperty for FullCompositionExclusionimpl BinaryProperty for UnifiedIdeographimpl BinaryProperty for Hyphenimpl BinaryProperty for BidiMirroredimpl BinaryProperty for SegmentStarterimpl BinaryProperty for GraphemeBaseimpl BinaryProperty for AsciiHexDigitimpl BinaryProperty for QuotationMarkimpl BinaryProperty for EmojiPresentationimpl BinaryProperty for PatternSyntaximpl BinaryProperty for EmojiModifierBaseimpl BinaryProperty for NfcInertimpl BinaryProperty for Dashimpl BinaryProperty for LogicalOrderExceptionimpl BinaryProperty for ChangesWhenNfkcCasefoldedimpl BinaryProperty for WhiteSpaceimpl BinaryProperty for IdStartimpl BinaryProperty for CaseIgnorableimpl BinaryProperty for TerminalPunctuationimpl BinaryProperty for HexDigitimpl BinaryProperty for BidiControlimpl BinaryProperty for SoftDottedimpl BinaryProperty for Graphimpl BinaryProperty for Printimpl BinaryProperty for Emojiimpl BinaryProperty for NfkdInertimpl BinaryProperty for Diacriticimpl BinaryProperty for NoncharacterCodePointimpl BinaryProperty for ChangesWhenUppercasedimpl BinaryProperty for XidStartimpl BinaryProperty for JoinControlimpl BinaryProperty for ChangesWhenCasemappedimpl BinaryProperty for VariationSelectorimpl BinaryProperty for Ideographicimpl BinaryProperty for Casedimpl BinaryProperty for SentenceTerminalimpl BinaryProperty for GraphemeLinkimpl BinaryProperty for Alphabeticimpl BinaryProperty for RegionalIndicatorimpl BinaryProperty for ExtendedPictographicimpl BinaryProperty for PrependedConcatenationMarkimpl BinaryProperty for EmojiModifierimpl BinaryProperty for NfkcInertimpl BinaryProperty for DefaultIgnorableCodePoint