Struct Baked

struct Baked

Baked data

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. In particular, the `DataProvider` implementations are only guaranteed to match with this version's `*_unstable` providers. Use with caution.

Implementations

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumGraphemeClusterBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongEastAsianWidthV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryPatternWhiteSpaceV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseGraphemeClusterBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryExtenderV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinarySoftDottedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongGraphemeClusterBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseLineBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongIndicSyllabicCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseWordBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumHangulSyllableTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryDeprecatedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryPrependedConcatenationMarkV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongLineBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryFullCompositionExclusionV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryAsciiHexDigitV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryIdStartV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortSentenceBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryChangesWhenCasefoldedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumIndicConjunctBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortWordBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryPrintV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryGraphV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryUppercaseV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryBasicEmojiV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumIndicSyllabicCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryEmojiModifierBaseV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryIdsTrinaryOperatorV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryChangesWhenNfkcCasefoldedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumJoiningTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryRegionalIndicatorV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortBidiClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseGeneralCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryNoncharacterCodePointV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortGeneralCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumLineBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseJoiningTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryEmojiV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinarySegmentStarterV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortHangulSyllableTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryHexDigitV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseVerticalOrientationV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryXidContinueV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryCaseIgnorableV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortCanonicalCombiningClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryLowercaseV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortJoiningTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryDashV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumScriptV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongSentenceBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryAlnumV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryHyphenV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongWordBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryCaseSensitiveV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumSentenceBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryTerminalPunctuationV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryDiacriticV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumVerticalOrientationV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryIdeographicV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryChangesWhenCasemappedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryQuotationMarkV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongBidiClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumWordBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryGraphemeBaseV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseGeneralCategoryMaskV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryVariationSelectorV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryBidiControlV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongGeneralCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseIndicSyllabicCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongHangulSyllableTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryEmojiModifierV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseSentenceBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseBidiClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyScriptWithExtensionsV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongCanonicalCombiningClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongJoiningTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryJoinControlV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryChangesWhenTitlecasedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongScriptV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortVerticalOrientationV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryPatternSyntaxV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryExtendedPictographicV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinarySentenceTerminalV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryXidStartV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryMathV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryDefaultIgnorableCodePointV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryAlphabeticV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryIdContinueV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumBidiClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryCasedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryNfcInertV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseEastAsianWidthV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortScriptV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortEastAsianWidthV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryUnifiedIdeographV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseHangulSyllableTypeV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumBidiMirroringGlyphV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortGraphemeClusterBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseScriptV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryNfdInertV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryEmojiComponentV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortIndicSyllabicCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameShortLineBreakV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryIdsBinaryOperatorV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumCanonicalCombiningClassV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryChangesWhenLowercasedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryNfkcInertV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameLongVerticalOrientationV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryRadicalV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryGraphemeExtendV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryWhiteSpaceV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryBidiMirroredV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumEastAsianWidthV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryNfkdInertV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryEmojiPresentationV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryGraphemeLinkV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryXdigitV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryBlankV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryLogicalOrderExceptionV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyEnumGeneralCategoryV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyBinaryChangesWhenUppercasedV1>, DataError>

impl DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<PropertyNameParseCanonicalCombiningClassV1>, DataError>

impl Debug for Baked

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Baked

impl RefUnwindSafe for Baked

impl Send for Baked

impl Sync for Baked

impl Unpin for Baked

impl UnsafeUnpin for Baked

impl UnwindSafe for Baked

impl<T> Any for Baked

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Baked

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Baked

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> ErasedDestructor for Baked

impl<T> From for Baked

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for Baked

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Baked

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Baked

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<Y> DataProvider for Baked

fn load(self: &Self, req: DataRequest<'_>) -> Result<DataResponse<NeverMarker<Y>>, DataError>