Struct ScriptWithExtensions
struct ScriptWithExtensions { ... }
A struct that represents the data for the Script and Script_Extensions properties.
✨ Enabled with the compiled_data Cargo feature.
Most useful methods are on ScriptWithExtensionsBorrowed obtained by calling [ScriptWithExtensions::as_borrowed()]
Examples
use ScriptWithExtensions;
use Script;
let swe = new;
// get the `Script` property value
assert_eq!; // U+0640 ARABIC TATWEEL
assert_eq!; // U+0650 ARABIC KASRA
assert_eq!; // // U+0660 ARABIC-INDIC DIGIT ZERO
assert_eq!; // U+FDF2 ARABIC LIGATURE ALLAH ISOLATED FORM
// get the `Script_Extensions` property value
assert_eq!;
assert_eq!;
assert_eq!;
assert_eq!;
// check containment of a `Script` value in the `Script_Extensions` value
// U+0650 ARABIC KASRA
assert!; // main Script value
assert!;
assert!;
assert!;
// get a `CodePointInversionList` for when `Script` value is contained in `Script_Extensions` value
let syriac = swe.get_script_extensions_set;
assert!; // ARABIC KASRA
assert!; // ARABIC-INDIC DIGIT ZERO
assert!; // ARABIC LIGATURE ALLAH ISOLATED FORM
assert!; // SYRIAC END OF PARAGRAPH
assert!; // SYRIAC BARREKH
Implementations
impl ScriptWithExtensions
fn new() -> ScriptWithExtensionsBorrowed<'static>Creates a new instance of
ScriptWithExtensionsBorrowedusing compiled data.✨ Enabled with the
compiled_dataCargo feature.fn try_new_unstable<impl DataProvider<PropertyScriptWithExtensionsV1> + ?Sized: DataProvider<PropertyScriptWithExtensionsV1> + ?Sized>(provider: &impl DataProvider<PropertyScriptWithExtensionsV1> + ?Sized) -> Result<Self, DataError>A version of
Self::newthat uses custom data provided by aDataProvider.⚠️ The bounds on provider may change over time, including in SemVer minor releases.fn as_borrowed(self: &Self) -> ScriptWithExtensionsBorrowed<'_>Construct a borrowed version of this type that can be queried.
This avoids a potential small underlying cost per API call (ex:
contains()) by consolidating it up front.
impl Debug for ScriptWithExtensions
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for ScriptWithExtensions
impl RefUnwindSafe for ScriptWithExtensions
impl Send for ScriptWithExtensions
impl Sync for ScriptWithExtensions
impl Unpin for ScriptWithExtensions
impl UnsafeUnpin for ScriptWithExtensions
impl UnwindSafe for ScriptWithExtensions
impl<T> Any for ScriptWithExtensions
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ScriptWithExtensions
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ScriptWithExtensions
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for ScriptWithExtensions
impl<T> From for ScriptWithExtensions
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ScriptWithExtensions
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ScriptWithExtensions
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ScriptWithExtensions
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>